library flutter_control;

import 'dart:io';

import 'core.dart';

export 'package:flutter/material.dart';

export './src/app_base.dart';
export './src/app_control.dart';
export './src/base_localization.dart';
export './src/base_prefs.dart';
export './src/base_theme.dart';
export './src/controller/base_controller.dart';
export './src/controller/base_model.dart';
export './src/controller/field_control.dart';
export './src/controller/route_control.dart';
export './src/entity/menu.dart';
export './src/factory.dart';
export './src/util/device.dart';
export './src/util/future_block.dart';
export './src/util/init_holder.dart';
export './src/util/parser.dart';
export './src/util/unit_id.dart';
export './src/widget/base_widget.dart';
export './src/widget/input_field.dart';
export './src/widget/navigation_stack.dart';
export './src/widget/stable_widget.dart';
export './src/widget/widget_provider.dart';

class ControlKey {
  static const String factory = 'factory';
  static const String localization = 'localization';
  static const String preferences = 'prefs';
  static const String control = 'control';
  static const String initData = 'init_data';
}

bool get debugMode => !inRelease();

bool inRelease({bool profileModeAsRelease: true}) {
  bool result = profileModeAsRelease ? true : bool.fromEnvironment('dart.vm.product'); // profile and release mode

  assert(() {
    result = false; // debug mode
    return true;
  }());

  return result;
}

T onPlatform<T>({
  Initializer<T> android,
  Initializer<T> ios,
  Initializer<T> mobile,
  Initializer<T> mac,
  Initializer<T> win,
  Initializer<T> desktop,
  Initializer<T> all,
}) {
  switch (Platform.operatingSystem) {
    case 'android':
      return _platformFuncSwitch(android, mobile, all);
    case 'ios':
      return _platformFuncSwitch(ios, mobile, all);
    case 'macos':
      return _platformFuncSwitch(mac, desktop, all);
    case 'windows':
      return _platformFuncSwitch(win, desktop, all);
    case 'linux':
      return _platformFuncSwitch(null, desktop, all);
    case 'fuchsia':
      return _platformFuncSwitch(null, desktop, all);
    default:
      return all == null ? null : all();
  }
}

T _platformFuncSwitch<T>(Initializer<T> platform, Initializer<T> alter, Initializer<T> all) {
  if (platform != null) {
    return platform();
  }

  if (alter != null) {
    return alter();
  }

  if (all != null) {
    return all();
  }

  return null;
}

void printDebug(Object object) {
  if (debugMode) {
    print(object);
  }
}
